# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "abl"


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&|||ABL817^ABL817 LE PRE||||||||1|20131105002605
    Q|1|^01119992196
    L|1|N"""
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "01119992196"}],
    }
    assert worklist == expected


def test_encode_void_order(self):
    message = self.order(
        worklist=self.void_worklist,
        context={
            "query": self.parse(
                """
            H|\\^&|||ABL817^ABL817 LE PRE||||||||1|20131105002605
            Q|1|^01119992196
            L|1|N"""
            )
        },
    )
    expected = """
    H|\\^&|||MCA||||||||1|20130715141912
    P|1
    O|1|01119992196
    L|1|N"""
    assert message == expected


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&|||MCA||||||||1|20130715141912
    P|1||L036666666||NYME^ANO||20110513|F|||||||||||||||||LOC(A:42)
    O|1|123456||^^^A\\^^^B|||20130603110342||||||||Serum|PRESCRIBER
    L|1|N"""
    assert message == expected


def test_decode_result(self):
    date = datetime.datetime(2012, 5, 23, 9, 13)
    worklist = self.decode(
        """
    H|\\^&|||ABL817^ABL817 LE PRE||||||||1|20120523091453
    P|1||080918000088||RENAUD^Annick||19381009|F|||||||||||||||||021()
    O|1|01119992196|Sample #^353|^^^Tube Iono + Lactate +|||||||||||Arteriel
    R|1|^^^Lac^M|1.1|mmol/L||H||F||cfou|20120523091300
    C|1|I|83|I
    R|2|^^^Ca++^M|2.28|meq/L||H||F
    C|1|I|83|I
    R|3|^^^K+^M|4.1|meq/L||N||F
    R|4|^^^Na+^M|134|meq/L||L||F
    C|1|G|repasse|G
    R|5|^^^Glu^M|9.7|mmol/L||H||F
    C|1|I|83|G
    R|6|^^^Crea^M|49|micromol/L||L||F
    C|1|I|84|I
    R|7|^^^tHb^M|9.9|g/dL||L||X
    C|1|I|84|I
    R|8|^^^T^I|37.0|Cel||||F
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "01119992196",
                "results": [
                    {
                        "code": "Lac",
                        "comments": [],
                        "date": date,
                        "flags": ["83", "H"],
                        "value": "1.1",
                        "operator": "cfou",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "Ca++",
                        "comments": [],
                        "date": date,
                        "flags": ["83", "H"],
                        "value": "2.28",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "K+",
                        "comments": [],
                        "date": date,
                        "flags": ["N"],
                        "value": "4.1",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "Na+",
                        "comments": ["repasse"],
                        "date": date,
                        "flags": ["L"],
                        "value": "134",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "Glu",
                        "comments": [],
                        "date": date,
                        "flags": ["H"],
                        "value": "9.7",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "Crea",
                        "comments": [],
                        "date": date,
                        "flags": ["84", "L"],
                        "value": "49",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "T",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "37.0",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "PRELEV",
                        "date": date,
                        "value": "Arteriel",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "HEURE",
                        "date": date,
                        "value": "09:13",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "ORIGPRL",
                        "date": date,
                        "value": "Tube Iono + Lactate +",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "OPE",
                        "date": date,
                        "value": "cfou",
                        "instrument": "ABL817 LE PRE",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    date = datetime.datetime(2013, 11, 4, 19, 0)
    worklist = self.decode(
        """
    H|\\^&|||ABL817^ABL817 LE PRE||||||||1|20131104190203
    P|1
    O|1||QC #^2669||||||||||||S7845^40
    R|1|^^^T^I|27.8|Cel||||F|||20131104190000
    R|2|^^^pH^M|7.404|||||F
    R|3|^^^pO2^M|108|mmHg||||F
    R|4|^^^pCO2^M|39.7|mmHg||||F
    R|5|^^^Ca++^M|0.62|mmol/L||||F
    R|6|^^^K+^M|3.7|meq/L||||F
    R|7|^^^Na+^M|141|meq/L||||F
    R|8|^^^Glu^M|5.6|mmol/L||||F
    R|9|^^^Lac^M|1.7|mmol/L||||F
    R|10|^^^Crea^M|?35|micromol/L||||F
    C|1|I|210|I
    R|11|^^^tHb^M|13.0|g/dL||||F
    R|12|^^^sO2^M|97.4|%||||F
    R|13|^^^B^M|751|mmHg||||F
    R|14|^^^pH(T)^C|7.401|||||F
    R|15|^^^pCO2(T)^C|40.2|mmHg||||F
    R|16|^^^pO2(T)^C|110|mmHg||||F
    R|17|^^^Crea(T)^C|?29|micromol/L||||F
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "40",
                "control_lot": "40",
                "results": [
                    {
                        "code": "T",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "27.8",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "pH",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "7.404",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "pO2",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "108",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "pCO2",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "39.7",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "Ca++",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "0.62",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "K+",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "3.7",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "Na+",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "141",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "Glu",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "5.6",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "Lac",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "1.7",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "Crea",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "?35",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "tHb",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "13.0",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "sO2",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "97.4",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "B",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "751",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "pH(T)",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "7.401",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "pCO2(T)",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "40.2",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "pO2(T)",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "110",
                        "instrument": "ABL817 LE PRE",
                    },
                    {
                        "code": "Crea(T)",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "?29",
                        "instrument": "ABL817 LE PRE",
                    },
                ],
            }
        ],
    }

    assert worklist == expected


def test_decode_control_qc_prefix_lot(self):
    self.configure(qc_prefix_lot=True)
    date = datetime.datetime(2013, 11, 4, 19, 0)
    worklist = self.decode(
        """
    H|\\^&|||ABL817^ABL817 LE PRE||||||||1|20131104190203
    P|1
    O|1||QC #^2669||||||||||||S7845^40
    R|1|^^^T^I|27.8|Cel||||F|||20131104190000
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "S784540",
                "control_lot": "S784540",
                "results": [
                    {
                        "code": "T",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "value": "27.8",
                        "instrument": "ABL817 LE PRE",
                    }
                ],
            }
        ],
    }
    assert worklist == expected
