# -*- coding: utf8 -*-

from __future__ import unicode_literals

import datetime

parser_class = "dr_dot"


def test_decode_result(self):
    date = datetime.datetime(2017, 7, 11, 13, 22)
    worklist = self.decode(
        """\"Feuille de résultats\";\"Opérateur\";\"Date\";\"Kit\";\"Lot\";\"Nom\";\"Antigène 1\";\"Valeur 1\";\"Antigène 2\";\"Valeur 2\";\"Antigène 3\";\"Valeur 3\";\"Antigène 4\";\"Valeur 4\";\"Antigène 5\";\"Valeur 5\";\"Antigène 6\";\"Valeur 6\";\"Antigène 7\";\"Valeur 7\";\"Antigène 8\";\"Valeur 8\";\"Antigène 9\";\"Valeur 9\";\"Antigène 10\";\"Valeur 10\";\"Antigène 11\";\"Valeur 11\";\"Antigène 12\";\"Valeur 12\"
\"1\";\"TOUMY\";\"11/07/17 13:22\";\"AD-ANADFD\";\"1703-01\";\"123456\";\"Sm\";\"0\";\"RNP 68kD/A/C\";\"0\";\"Sm/RNP\";\"0\";\"SSA\";\"0\";\"SSB\";\"0\";\"Scl-70\";\"0\";\"PM-Scl\";\"0\";\"Ku\";\"0\";\"CENP-A/B\";\"0\";\"PCNA\";\"0\";\"Mi-2\";\"0\";\"DFS-70\";\"0\"
\"1\";\"TOUMY\";\"11/07/17 13:22\";\"AD-ANADFD\";\"1703-01\";\"123451\";\"Sm\";\"0\";\"RNP 68kD/A/C\";\"0\";\"Sm/RNP\";\"0\";\"SSA\";\"0\";\"SSB\";\"0\";\"Scl-70\";\"26\";\"PM-Scl\";\"0\";\"Ku\";\"0\";\"CENP-A/B\";\"21\";\"PCNA\";\"0\";\"Mi-2\";\"0\";\"DFS-70\";\"0\""""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "AD-ANADFDSm",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDRNP 68kD/A/C",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDSm/RNP",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDSSA",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDSSB",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDScl-70",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDPM-Scl",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDKu",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDCENP-A/B",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDPCNA",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDMi-2",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDDFS-70",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                ],
                "sample_id": "123456",
                "type": "patient",
            },
            {
                "results": [
                    {
                        "code": "AD-ANADFDSm",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDRNP 68kD/A/C",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDSm/RNP",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDSSA",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDSSB",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDScl-70",
                        "value": "26",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDPM-Scl",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDKu",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDCENP-A/B",
                        "value": "21",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDPCNA",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDMi-2",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                    {
                        "code": "AD-ANADFDDFS-70",
                        "value": "0",
                        "date": date,
                        "operator": "TOUMY",
                    },
                ],
                "sample_id": "123451",
                "type": "patient",
            },
        ],
    }
    assert worklist == expected
