# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "epicenter"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&|||||||||||V1.0|20130715141912
    P|1||036666666||NYME^ANO||20110513|F||||||||||Information clinique|||||20130511103030||237|||||||LOC
    O|1|123456^1^1||^^^A|||20130513114242||||||||Serum|ATTENDING
    R|1|^^^ID|MALDI^1|||||F|||20110506121400
    P|2||036666666||NYME^ANO||20110513|F||||||||||Information clinique|||||20130511103030||237|||||||LOC
    O|1|123456^2^2||^^^A|||20130513114242||||||||Serum|ATTENDING
    R|1|^^^ID|MALDI^2|||||F|||20110506121400
    L|1
    """
    assert message == expected


def test_encode_order_with_option(self):
    self.configure(epicenter_test_start_date=30)
    message = self.order()
    expected = """
    H|\\^&|||||||||||V1.0|20130715141912
    P|1||036666666||NYME^ANO||20110513|F||||||||||Information clinique|||||20130511103030||237|||||||LOC
    O|1|123456^1^1||^^^A|||20130513114242||||||||Serum|ATTENDING
    R|1|^^^ID|MALDI^1|||||F|||20110506114400
    P|2||036666666||NYME^ANO||20110513|F||||||||||Information clinique|||||20130511103030||237|||||||LOC
    O|1|123456^2^2||^^^A|||20130513114242||||||||Serum|ATTENDING
    R|1|^^^ID|MALDI^2|||||F|||20110506114400
    L|1
    """
    assert message == expected


def test_decode_result_hemoc(self):
    date = datetime.datetime(2019, 3, 12, 16, 22, 24)
    for sep in (":", "H", ",", ""):
        self.configure(epicenter_hour_min_sep=sep)
        worklist = self.decode(
            """
        H|\\^&|||Becton Dickinson||||||||V1.0|20190313145627
        P|1||188675||BK ESSAI||20060112|F
        O|1|13031912||^^^MGIT_960_GND^430184154859|R||20190313145042|||||||20190313145042|BK|||||||20190313145607
        R|1|^^^GND_MGIT^430184154859|INST_POSITIVE^443|||||F|||20190219111313|20190312162224\\20190308150229|MGIT960^^42^1^A-C02
        L|1|N
        """
        )
        expected = {
            "context": "result",
            "samples": [
                {
                    "type": "patient",
                    "sample_id": "13031912",
                    "results": [
                        {
                            "code": "MGIT_960_GNDGND_MGIT",
                            "comments": [],
                            "date": date,
                            "value": "INST_POSITIVE",
                            "instrument": "MGIT960",
                        },
                        {
                            "code": "BOTTLE_ID",
                            "date": date,
                            "instrument": "MGIT960",
                            "value": "430184154859",
                        },
                        {
                            "code": "BOTTLE_RACK",
                            "date": date,
                            "instrument": "MGIT960",
                            "value": "A-C02",
                        },
                        {"code": "INSTRUMENT", "date": date, "value": "MGIT960"},
                        {
                            "code": "MGIT_960_GND_INSTRUMENT",
                            "date": date,
                            "value": "A-C02_1",
                        },
                        {
                            "code": "MGIT_960_GNDINTRODUCE_DATETIME",
                            "value": "2019/02/19 11:13:13",
                        },
                        {
                            "code": "MGIT_960_GNDBOTTLE_INTRODUCE_DATETIME",
                            "value": "20190219111313",
                        },
                        {"code": "MGIT_960_GNDINTRODUCE_DATE", "value": "2019/02/19"},
                        {"code": "MGIT_960_GNDINTRODUCE_TIME", "value": "11:13:13"},
                        {
                            "code": "MGIT_960_GNDINTRODUCTION_DATE",
                            "value": "19/02/2019",
                        },
                        {"code": "MGIT_960_GNDINTRODUCTION_HEURE", "value": "11:13"},
                        {
                            "code": "MGIT_960_GNDDETERMINED_DATETIME",
                            "value": "20190312162224",
                        },
                        {"code": "MGIT_960_GNDDETERMINED_DATE", "value": "2019/03/12"},
                        {"code": "MGIT_960_GNDDETERMINED_TIME", "value": "16:22:24"},
                        {
                            "code": "MGIT_960_GNDDATE_DETERMINATION",
                            "value": "12/03/2019",
                        },
                        {"code": "MGIT_960_GNDHEURE_DETERMINATION", "value": "16:22"},
                        {
                            "code": "MGIT_960_GNDGROWTH_TIME",
                            "value": sep.join(("509", "09")),
                        },
                        {
                            "code": "MGIT_960_GNDPOSITIVITY_DATETIME",
                            "value": "20190312162224",
                        },
                        {"code": "MGIT_960_GNDPOSITIVITY_DATE", "value": "2019/03/12"},
                        {"code": "MGIT_960_GNDPOSITIVITE_DATE", "value": "12/03/2019"},
                        {"code": "MGIT_960_GNDPOSITIVITY_TIME", "value": "16:22:24"},
                        {"code": "MGIT_960_GNDPOSITIVITE_HEURE", "value": "16:22"},
                        {
                            "code": "TIME_TO_DETECTION_POSITIVITY_MGIT_960_GND",
                            "value": sep.join(("509", "09")),
                        },
                    ],
                }
            ],
        }
        assert worklist == expected


def test_decode_result_type_streak(self):
    worklist = self.decode(
        """
    H|\\^&|||Becton Dickinson||||||||V1.0|20190416163846
    P|1||71839||CASADEVALL JEAN||19450625|M||||||||||||||||||||||||MRE
    O|1|076090416184||^^^INNOVA|||20190416102000|||||||20190416120716|ECBU|REMLO||||||20190416163846
    R|1|^^^STREAK|INST_COMPLETE|||||F|||20190416163737|20190416163846|INNOVA^^^1^2-2-5
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "076090416184",
                "type": "patient",
                "results": [{"code": "STREAK_ECBU", "value": "INST_COMPLETE"}],
            }
        ],
    }
    assert worklist == expected


def test_decode_result_production(self):
    self.configure(
        epicenter_liste_resistance_marker_activation=True,
        epicenter_liste_resistance_marker="BMR=COMMENT1",
    )
    date = datetime.datetime(2018, 5, 31, 17, 48, 19)
    worklist = self.decode(
        """
    H|\\^&|||Becton Dickinson||||||||V1.0|20180731175653
    P|1||B1101400077||TEST PATIENT||19661208|F||135 CHEMIN DES PAQUERETTES,  66100||||||||||||||||||||||PUIJL
    O|1|12345678^1^ESCCOL^E||^^^ISOLATE RESULT|||20180531174819|||||||20180531174819|ECBU|||||||20180602093205||||||UNK
    C|1||Test  ESBL positif|I
    R|1|^^^ID|^ESCCOL^^ESBL^BMR|||||F
    R|2|^^^AST^^AM|^<=2^S^S^^NMIC-417|||||F
    R|3|^^^AST^^AN|^<=4^S^S^^NMIC-417|||||F
    R|4|^^^AST^^ATM|^<=1^S^S^^NMIC-417|||||F
    R|5|^^^AST^^CAZ|^<=0,5^S^S^^NMIC-417|||||F
    R|6|^^^AST^^CFM|^<=0,5^S^S^^NMIC-417|||||F
    R|7|^^^AST^^CIP|^<=0,25^S^S^^NMIC-417|||||F
    R|8|^^^AST^^CEX|^<=4^S^S^^NMIC-417|||||F
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "12345678",
                "results": [
                    {
                        "code": "ECBU",
                        "date": date,
                        "value": [
                            {
                                "sub_code": "1",
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_AM",
                                        "mic": "<=2",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_AN",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_ATM",
                                        "mic": "<=1",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CAZ",
                                        "mic": "<=0,5",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CFM",
                                        "mic": "<=0,5",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CIP",
                                        "mic": "<=0,25",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CEX",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    },
                                ],
                                "value": "G_ESCCOL",
                            }
                        ],
                        "nom_antibiogramme": "NMIC-417",
                        "comments": ["COMMENT1", "Test  ESBL positif"],
                    },
                    {"code": "GERME_1_ECBU", "value": "G_ESCCOL"},
                    {
                        "code": "IDENT_ECBU",
                        "value": {
                            "germes": [{"id": "G_ESCCOL", "rang": 1}],
                            "seq": "0",
                            "type_resultat": "identification_germes",
                        },
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_result_production_no_transcode(self):
    date = datetime.datetime(2018, 5, 31, 17, 48, 19)
    worklist = self.decode(
        """
    H|\\^&|||Becton Dickinson||||||||V1.0|20180731175653
    P|1||B1101400077||TEST PATIENT||19661208|F||135 CHEMIN DES PAQUERETTES,  66100||||||||||||||||||||||PUIJL
    O|1|12345678^1^ESCCOL^E||^^^ISOLATE RESULT|||20180531174819|||||||20180531174819|ECBU|||||||20180602093205||||||UNK
    C|1||Test  ESBL positif|I
    R|1|^^^ID|^ESCCOL^^ESBL^BMR|||||F
    R|2|^^^AST^^AM|^<=2^S^S^^NMIC-417|||||F
    R|3|^^^AST^^AN|^<=4^S^S^^NMIC-417|||||F
    R|4|^^^AST^^ATM|^<=1^S^S^^NMIC-417|||||F
    R|5|^^^AST^^CAZ|^<=0,5^S^S^^NMIC-417|||||F
    R|6|^^^AST^^CFM|^<=0,5^S^S^^NMIC-417|||||F
    R|7|^^^AST^^CIP|^<=0,25^S^S^^NMIC-417|||||F
    R|8|^^^AST^^CEX|^<=4^S^S^^NMIC-417|||||F
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "12345678",
                "results": [
                    {
                        "code": "ECBU",
                        "date": date,
                        "value": [
                            {
                                "sub_code": "1",
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_AM",
                                        "mic": "<=2",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_AN",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_ATM",
                                        "mic": "<=1",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CAZ",
                                        "mic": "<=0,5",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CFM",
                                        "mic": "<=0,5",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CIP",
                                        "mic": "<=0,25",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CEX",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    },
                                ],
                                "value": "G_ESCCOL",
                                "phenotypes": ["ESBL", "BMR"],
                            }
                        ],
                        "nom_antibiogramme": "NMIC-417",
                        "comments": ["Test  ESBL positif"],
                    },
                    {"code": "GERME_1_ECBU", "value": "G_ESCCOL"},
                    {
                        "code": "IDENT_ECBU",
                        "value": {
                            "germes": [{"id": "G_ESCCOL", "rang": 1}],
                            "seq": "0",
                            "type_resultat": "identification_germes",
                        },
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_result_bloodculture_positive(self):
    worklist = self.decode(
        """
    H|\\^&|||Becton Dickinson||||||||V1.0|20181214101110
    P|1||19273||TEST||20130101|M
    O|1|813981214007||^^^PLUSAEF^449210547259|||20181213110305|||||||20181213110305|HEMOC|X||||||20181214101015
    R|1|^^^GND^449210547259|Manual Positive|||||F|||20181213110305|20181214100757\\20181213110305|BACTECFX^92^9^1
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "813981214007",
                "results": [
                    {
                        "code": "PLUSAEFGND",
                        "comments": [],
                        "date": datetime.datetime(2018, 12, 14, 10, 7, 57),
                        "instrument": "BACTECFX-92",
                        "value": "Manual Positive",
                    },
                    {
                        "code": "BOTTLE_ID",
                        "date": datetime.datetime(2018, 12, 14, 10, 7, 57),
                        "instrument": "BACTECFX-92",
                        "value": "449210547259",
                    },
                    {
                        "code": "INSTRUMENT",
                        "date": datetime.datetime(2018, 12, 14, 10, 7, 57),
                        "value": "BACTECFX-92",
                    },
                    {
                        "code": "PLUSAEFINTRODUCE_DATETIME",
                        "value": "2018/12/13 11:03:05",
                    },
                    {
                        "code": "PLUSAEFBOTTLE_INTRODUCE_DATETIME",
                        "value": "20181213110305",
                    },
                    {"code": "PLUSAEFINTRODUCE_DATE", "value": "2018/12/13"},
                    {"code": "PLUSAEFINTRODUCE_TIME", "value": "11:03:05"},
                    {"code": "PLUSAEFINTRODUCTION_DATE", "value": "13/12/2018"},
                    {"code": "PLUSAEFINTRODUCTION_HEURE", "value": "11:03"},
                    {"code": "PLUSAEFDETERMINED_DATETIME", "value": "20181214100757"},
                    {"code": "PLUSAEFDETERMINED_DATE", "value": "2018/12/14"},
                    {"code": "PLUSAEFDETERMINED_TIME", "value": "10:07:57"},
                    {"code": "PLUSAEFDATE_DETERMINATION", "value": "14/12/2018"},
                    {"code": "PLUSAEFHEURE_DETERMINATION", "value": "10:07"},
                    {"code": "PLUSAEFGROWTH_TIME", "value": "23H04"},
                    {"code": "PLUSAEFPOSITIVITY_DATETIME", "value": "20181214100757"},
                    {"code": "PLUSAEFPOSITIVITY_DATE", "value": "2018/12/14"},
                    {"code": "PLUSAEFPOSITIVITE_DATE", "value": "14/12/2018"},
                    {"code": "PLUSAEFPOSITIVITY_TIME", "value": "10:07:57"},
                    {"code": "PLUSAEFPOSITIVITE_HEURE", "value": "10:07"},
                    {"code": "TIME_TO_DETECTION_POSITIVITY_PLUSAEF", "value": "23H04"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_result_hemoculture(self):
    worklist = self.decode(
        """
    H|\\^&|||Becton Dickinson||||||||V1.0|20180731174449
    P|1||||||||||||||||||||||20170808000000||121F|||||||CVIS|CLINI
    O|1|813070811193||^^^PLUSAEF^449231647180|||20170811132800|||||||20170811132800|HEMOC|MMIR||||||20170817140038
    R|1|^^^GND^449231647180|INST_NEGATIVE|||||F|||20170811133852|20170817140038\\20170811133852|BT9000^92^6^A1
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "813070811193",
                "results": [
                    {
                        "code": "PLUSAEFGND",
                        "value": "INST_NEGATIVE",
                        "comments": [],
                        "date": datetime.datetime(2017, 8, 17, 14, 0, 38),
                        "instrument": "BT9000-92",
                    },
                    {
                        "code": "BOTTLE_ID",
                        "value": "449231647180",
                        "date": datetime.datetime(2017, 8, 17, 14, 0, 38),
                        "instrument": "BT9000-92",
                    },
                    {
                        "code": "INSTRUMENT",
                        "date": datetime.datetime(2017, 8, 17, 14, 0, 38),
                        "value": "BT9000-92",
                    },
                    {
                        "code": "PLUSAEFINTRODUCE_DATETIME",
                        "value": "2017/08/11 13:38:52",
                    },
                    {
                        "code": "PLUSAEFBOTTLE_INTRODUCE_DATETIME",
                        "value": "20170811133852",
                    },
                    {"code": "PLUSAEFINTRODUCE_DATE", "value": "2017/08/11"},
                    {"code": "PLUSAEFINTRODUCE_TIME", "value": "13:38:52"},
                    {"code": "PLUSAEFINTRODUCTION_DATE", "value": "11/08/2017"},
                    {"code": "PLUSAEFINTRODUCTION_HEURE", "value": "13:38"},
                    {"code": "PLUSAEFDETERMINED_DATETIME", "value": "20170817140038"},
                    {"code": "PLUSAEFDETERMINED_DATE", "value": "2017/08/17"},
                    {"code": "PLUSAEFDETERMINED_TIME", "value": "14:00:38"},
                    {"code": "PLUSAEFDATE_DETERMINATION", "value": "17/08/2017"},
                    {"code": "PLUSAEFHEURE_DETERMINATION", "value": "14:00"},
                    {"code": "PLUSAEFGROWTH_TIME", "value": "144H21"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_result(self):
    date = datetime.datetime(2018, 5, 10, 17, 39, 14)
    worklist = self.decode(
        """
    H|\\^&|||Becton Dickinson||||||||V1.0|20040512091029
    P|1||1953080200171784||ANO NYME||19530802|F||6 Impasse Leonce Couture,TOULOUSE 31200||||||||||||||||||||||AG
    O|1|61489110^1^ESCCOL||^^^ISOLATE RESULT|||20180510000000|||||||20180510173914|CBU|VALM||||||||||||UNK
    C|1||Commentaire isolat|I
    C|2||Commentaire specimen|S
    R|1|^^^ID|^ESCCOL
    R|2|^^^AST^^AM|^<=4^S^S^^UNMIC/ID-2
    R|3|^^^AST^^AN|^<=8^S^S^^UNMIC/ID-2
    R|4|^^^AST^^ATM|^<=2^S^S^^UNMIC/ID-2
    R|5|^^^AST^^CAZ|^<=1^S^S^^UNMIC/ID-2
    R|6|^^^AST^^CF|^8^S^S^^UNMIC/ID-2
    R|7|^^^AST^^CIP|^<=0,5^S^S^^UNMIC/ID-2
    R|8|^^^AST^^CTX|^<=4^S^S^^UNMIC/ID-2
    R|9|^^^AST^^FM|^<=32^S^S^^UNMIC/ID-2
    R|10|^^^AST^^FOX|^<=4^S^S^^UNMIC/ID-2
    R|11|^^^AST^^GM|^<=2^S^S^^UNMIC/ID-2
    R|12|^^^AST^^IPM|^<=1^S^S^^UNMIC/ID-2
    R|13|^^^AST^^NA|^<=4^S^S^^UNMIC/ID-2
    R|14|^^^AST^^NET|^<=2^S^S^^UNMIC/ID-2
    R|15|^^^AST^^NN|^<=2^S^S^^UNMIC/ID-2
    R|16|^^^AST^^NOR|^<=1^S^S^^UNMIC/ID-2
    R|17|^^^AST^^OFX|^<=1^S^S^^UNMIC/ID-2
    R|18|^^^AST^^SXT|^<=2/38^S^S^^UNMIC/ID-2
    R|19|^^^AST^^TIC|^<=8^S^S^^UNMIC/ID-2
    R|20|^^^AST^^ZOX|^<=4^S^S^^UNMIC/ID-2
    R|21|^^^AST^^AXC|^<=2/2^S^S^^UNMIC/ID-2
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "61489110",
                "results": [
                    {
                        "code": "CBU",
                        "date": date,
                        "value": [
                            {
                                "sub_code": "1",
                                "antibiogram": [
                                    {
                                        "antibiotic": "A_AM",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_AN",
                                        "mic": "<=8",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_ATM",
                                        "mic": "<=2",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CAZ",
                                        "mic": "<=1",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CF",
                                        "mic": "8",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CIP",
                                        "mic": "<=0,5",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_CTX",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_FM",
                                        "mic": "<=32",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_FOX",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_GM",
                                        "mic": "<=2",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_IPM",
                                        "mic": "<=1",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_NA",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_NET",
                                        "mic": "<=2",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_NN",
                                        "mic": "<=2",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_NOR",
                                        "mic": "<=1",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_OFX",
                                        "mic": "<=1",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_SXT",
                                        "mic": "<=2/38",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_TIC",
                                        "mic": "<=8",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_ZOX",
                                        "mic": "<=4",
                                        "sensitivity": "S",
                                    },
                                    {
                                        "antibiotic": "A_AXC",
                                        "mic": "<=2/2",
                                        "sensitivity": "S",
                                    },
                                ],
                                "value": "G_ESCCOL",
                            }
                        ],
                        "nom_antibiogramme": "UNMIC/ID-2",
                        "comments": ["Commentaire isolat", "Commentaire specimen"],
                    },
                    {"code": "GERME_1_CBU", "value": "G_ESCCOL"},
                    {
                        "code": "IDENT_CBU",
                        "value": {
                            "germes": [{"id": "G_ESCCOL", "rang": 1}],
                            "seq": "0",
                            "type_resultat": "identification_germes",
                        },
                    },
                ],
            }
        ],
    }
    assert worklist == expected
