# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

from driverng.tests import unindent
from driverng import Worklist

parser_class = "piano"


def test_order(self):
    result = self.order()
    expected = """H|\\^&
        P|1|036666666|||NYME^ANO||20110513|F
        O|1|123456||^^^A\\^^^B
        L|1"""
    assert result == expected


def test_result(self):
    date = datetime.datetime(2013, 12, 18, 11, 25, 51)
    result = self.decode(
        """
    H|\\^&|||G8-3|||||||||
    P|1|01130704189694|||ANO^NYME||19341102|U
    O|1|360412185659||^^^505^1^|||||||||||Sp.1
    R|1|^^^505|6.50|%||N||F||JG||20131218112551
    C|1|l|.|l
    O|2|360412185659||^^^605^1^|||||||||||Sp.1
    R|2|^^^605|48|mmol||N||F||JG||20131218112551
    C|2|l|.|l
    O|3|360412185659||^^^503^1^|||||||||||Sp.1
    R|3|^^^503|0.45|%||N||F||JG||20131218112551
    C|3|l|.|l
    L|1"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "360412185659",
                "type": "patient",
                "results": [
                    {
                        "flags": ["N"],
                        "instrument": "G8-3",
                        "date": date,
                        "value": "6.50",
                        "code": "505",
                        "operator": "JG",
                    },
                    {
                        "flags": ["N"],
                        "instrument": "G8-3",
                        "date": date,
                        "value": "48",
                        "code": "605",
                        "operator": "JG",
                    },
                    {
                        "flags": ["N"],
                        "instrument": "G8-3",
                        "date": date,
                        "value": "0.45",
                        "code": "503",
                        "operator": "JG",
                    },
                ],
            }
        ],
    }
    assert result == expected


def test_qc(self):
    result = self.decode(
        """
    H|\\^&|||G8-4|||||||||
    P|1||||CQ HAUT AB20150^||18991230|U
    O|1|1020502||^^^505^1^|||||||||||Control
    R|1|^^^505|9.74|%||N||F||JG||20131218094630
    C|1|l|.|l
    L|1"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "1020502",
                "control_lot": "1020502",
                "type": "control",
                "results": [
                    {
                        "flags": ["N"],
                        "operator": "JG",
                        "instrument": "G8-4",
                        "date": datetime.datetime(2013, 12, 18, 9, 46, 30),
                        "value": "9.74",
                        "code": "505",
                    }
                ],
            }
        ],
    }
    assert result == expected


def test_qc_piano_etendu(self):
    result = self.decode(
        """
    H|\\^&|||g11-1|||||||||20180918114026
    P|1
    O|1|000000000QCN2||^^^505^1|||||||Q||||Sp.1
    R|1|^^^505|9.77|||N||F||auto||20180918113852|g11-1
    L|1
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "000000000QCN2",
                "type": "control",
                "control_lot": "000000000QCN2",
                "results": [
                    {
                        "flags": ["N"],
                        "operator": "auto",
                        "instrument": "g11-1",
                        "date": datetime.datetime(2018, 9, 18, 11, 38, 52),
                        "code": "505",
                        "value": "9.77",
                    }
                ],
            }
        ],
    }
    assert result == expected


def test_ignore_query_all(self):
    result = self.parser.enregistrer(
        unindent(
            """H|\\^&||||||||||||
        Q|1|^ALL||ALL
        L|1"""
        )
    )
    expected = False
    assert result == expected


def test_query(self):
    result = self.decode(
        """
    H|\\^&||||||||||||
    Q|1|^123456789||ALL
    L|1"""
    )
    expected = {
        "context": "query",
        "samples": [{"sample_id": "123456789", "type": "patient"}],
    }
    assert result == expected


def test_void_order(self):
    result = self.order(
        worklist=Worklist(context="order"),
        context={
            "query": self.parse(
                """
    H|\\^&||||||||||||
    Q|1|^123456789||ALL
    L|1"""
            )
        },
    )
    expected = """
    H|\\^&
    L|1"""
    assert result == expected
