# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "urgentec"


def test_decode_result_amplification(self):
    worklist = self.decode(
        """
    MSH|^~\\&|FastFinder||||20181025115927||OML^O21||P|2.5|||AL|N
    OBR|1|575027601||Target A|||20181025115913|||||||||||||||||||||||||||john.doe@ugentec.com
    OBX|1|ST|Target A||Positive
    OBX|2|ST|Target A_EF||4.861438459
    OBX|3|ST|Target A_CQ||27.98
    NTE|7|L|User comment
    OBR|2|4876215548||Target A|||20181025121826|||||||||||||||||||||||||||john.doe@ugentec.com
    OBX|1|ST|Target A||Positive
    OBX|2|ST|Target A_EF||4.861438459
    OBX|3|ST|Target A_CQ||27.98
    NTE|7|L|TOBEREPEATED
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "Target A",
                        "date": datetime.datetime(2018, 10, 25, 11, 59, 13),
                        "value": "Positive",
                    },
                    {
                        "code": "Target A_EF",
                        "date": datetime.datetime(2018, 10, 25, 11, 59, 13),
                        "value": "4.861438459",
                    },
                    {
                        "code": "Target A_CQ",
                        "date": datetime.datetime(2018, 10, 25, 11, 59, 13),
                        "flags": ["User comment"],
                        "value": "27.98",
                    },
                ],
                "sample_id": "575027601",
                "type": "patient",
            },
            {
                "results": [
                    {
                        "code": "Target A",
                        "date": datetime.datetime(2018, 10, 25, 12, 18, 26),
                        "value": "Positive",
                    },
                    {
                        "code": "Target A_EF",
                        "date": datetime.datetime(2018, 10, 25, 12, 18, 26),
                        "value": "4.861438459",
                    },
                    {
                        "code": "Target A_CQ",
                        "date": datetime.datetime(2018, 10, 25, 12, 18, 26),
                        "flags": ["TOBEREPEATED"],
                        "value": "27.98",
                    },
                ],
                "sample_id": "4876215548",
                "type": "patient",
            },
        ],
    }
    assert worklist == expected


def test_decode_result_melt(self):
    date = datetime.datetime(2018, 10, 25, 11, 59, 13)
    worklist = self.decode(
        """
    MSH|^~\\&|FastFinder||||20181025115927||OML^O21||P|2.5|||AL|N
    OBR|1|4876215541||Target A|||20181025115913|||||||||||||||||||||||||||john.doe@ugentec.com
    OBX|1|ST|Target A||Positive
    OBX|2|ST|Target A_TM||27.98
    NTE|6|L|TOBEREPEATED
    NTE|7|L|Control Invalid
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "Target A", "date": date, "value": "Positive"},
                    {
                        "code": "Target A_TM",
                        "date": date,
                        "value": "27.98",
                        "flags": ["TOBEREPEATED", "Control Invalid"],
                    },
                ],
                "sample_id": "4876215541",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected
