# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

import driverng
from driverng.tests import BaseTest
from driverng import utils


class VidasxmlTest(BaseTest):
    MAPPING_CLASS = "vidasxml"

    def unindent(self, data):
        data = "".join(
            [li.lstrip().replace("\t", "") for li in data.splitlines() if li.strip()]
        )
        return utils.prettify_xml(data.encode(self.F.ENCODING))

    def test_order(self):
        self.assertOrderMessageEqual(
            self.WORKLIST_NEW_ADD_DEL,
            """
            <?xml version="1.0" encoding="UTF-8"?>
            <lisMessage xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="ASTM.xsd">
            <header>
                <version>1394-97</version>
                <dateTime>20130715141912</dateTime>
            </header>
            <request>
            <patientInformation>
                <patientIdentifier>036666666</patientIdentifier>
                <lastName>NYME ANO</lastName>
                <sex>F</sex>
                <birthdate>20110513</birthdate>
            </patientInformation>
            <testOrder>
                <specimen>
                    <specimenIdentifier>123456</specimenIdentifier>
                </specimen>
                <test>
                    <universalIdentifier>
                        <testIdentifier>A</testIdentifier>
                        <dilution>1:10</dilution>
                    </universalIdentifier>
                </test>
                <test>
                    <universalIdentifier>
                        <testIdentifier>B</testIdentifier>
                    </universalIdentifier>
                </test>
            </testOrder>
            </request>
            </lisMessage>
            """,
        )

    def test_resultat(self):
        date = datetime.datetime(2013, 6, 26, 15, 28, 28)
        lots_reactifs = [
            {"peremption": datetime.datetime(2014, 3, 26, 0, 0), "ref": "140326-1"},
            {"ref": "140326-0"},
        ]
        self.assertResultEqual(
            """
        <aiMessage>
        <header>
            <senderName>bioMerieux</senderName>
            <version>1394-97</version>
            <dateTime>20130924130241</dateTime>
            <instrumentName>VN03049</instrumentName>
            <serialNumber>VN03012</serialNumber>
        </header>
        <requestResult>
            <patientInformation>
                <patientIdentifier>115941</patientIdentifier>
                <lastName>BABONNEAU_DOMINIQUE</lastName>
                <sex>F</sex>
            </patientInformation>
            <testOrder>
                <specimen>
                    <specimenIdentifier>00582638</specimenIdentifier>
                </specimen>
                <test>
                    <actionCode>N</actionCode>
                    <universalIdentifier>
                        <testIdentifier>CORS</testIdentifier>
                        <dilution>1</dilution>
                        <testName>Cortisol S</testName>
                    </universalIdentifier>
                    <result>
                        <value>10.81|POSITIF</value>
                            <unit>ug/l</unit>
                            <abnormalFlags>valid</abnormalFlags>
                            <abnormalFlags>manipet</abnormalFlags>
                            <resultStatus>F</resultStatus>
                            <operatorName>vidas</operatorName>
                            <resultDateTime>20130626152828</resultDateTime>
                            <bmxResultData>
                            <disposable>
                                <reference>CT2OQ2</reference>
                                <disposableType>VIDAS_SPR</disposableType>
                                <expirationDate>20140326</expirationDate>
                            </disposable>
                            <disposable>
                                <reference>CT2OQ2</reference>
                                <disposableType>VIDAS_SPR</disposableType>
                                <lotNumber>140326-1</lotNumber>
                                <expirationDate>20140326</expirationDate>
                            </disposable>
                            <disposable>
                                <reference>FVGDQ2QP6</reference>
                                <disposableType>VIDAS_STRIP</disposableType>
                                <lotNumber>140326-0</lotNumber>
                            </disposable>
                            </bmxResultData>
                    </result>
                </test>
            </testOrder>
        </requestResult>
        </aiMessage>""",
            {
                "00582638": {
                    "resultats": [
                        {
                            "analyseur": "VN03012",
                            "alarmes": ["valid", "manipet"],
                            "date": date,
                            "resu": "10.81",
                            "test": "CORS",
                            "operator": "vidas",
                            "lots_reactifs": lots_reactifs,
                        },
                        {
                            "analyseur": "VN03012",
                            "alarmes": ["valid", "manipet"],
                            "date": date,
                            "resu": "POSITIF",
                            "test": "CORSI",
                            "operator": "vidas",
                            "lots_reactifs": lots_reactifs,
                        },
                    ]
                }
            },
        )

    def test_qc(self):
        date = datetime.datetime(2013, 11, 5, 12, 24, 49)
        self._F = driverng.get(self.MAPPING_CLASS)(qc_prefix="CQ")
        self.assertQCEqual(
            """
        <aiMessage>
        <header>
            <senderName>bioMerieux</senderName>
            <version>1394-97</version>
            <dateTime>20131105122451</dateTime>
            <instrumentName>VN03187</instrumentName>
            <serialNumber>VN03187</serialNumber>
        </header>
        <requestResult>
            <patientInformation>
                <patientIdentifier></patientIdentifier>
                <lastName></lastName>
                <location></location>
            </patientInformation>
            <testOrder>
                <specimen>
                    <specimenIdentifier>CQ 140326-0</specimenIdentifier>
                </specimen>
                <test>
                    <actionCode>N</actionCode>
                    <universalIdentifier>
                        <testIdentifier>HIV6</testIdentifier>
                        <dilution>1</dilution>
                        <testName>HIV DUO Quick</testName>
                    </universalIdentifier>
                    <result>
                        <value>1.21|POSITIVE</value>
                        <abnormalFlags>valid</abnormalFlags>
                        <abnormalFlags>manpipet</abnormalFlags>
                        <resultStatus>F</resultStatus>
                        <operatorName>vidas</operatorName>
                        <resultDateTime>20131105122449</resultDateTime>
                        <bmxResultData>
                        <disposable>
                            <reference>CT2OQ2</reference>
                            <disposableType>VIDAS_SPR</disposableType>
                            <lotNumber>CT2</lotNumber>
                            <expirationDate>20140326</expirationDate>
                        </disposable>
                        <disposable>
                            <reference>FVGDQ2QP6</reference>
                            <disposableType>VIDAS_STRIP</disposableType>
                            <lotNumber>140326-0</lotNumber>
                            <expirationDate>20140326</expirationDate>
                        </disposable>
                        </bmxResultData>
                    </result>
                </test>
            </testOrder>
        </requestResult>
        </aiMessage>""",
            [
                {
                    "date": date,
                    "lot": "CQ 140326-0",
                    "resu": "1.21",
                    "test": "HIV6",
                    "analyseur": "VN03187",
                },
                {
                    "date": date,
                    "lot": "CQ 140326-0",
                    "resu": "POSITIVE",
                    "test": "HIV6I",
                    "analyseur": "VN03187",
                },
            ],
        )
